@@ -2,12 +2,12 @@ class CorePlugin:
     def __init__(self, bot):
         self.bot = bot
 
-
     def startup(self, config):
         self.bot.registerCommand("help", self.cmd_help)
         self.bot.registerCommand("h", self.cmd_help)
         self.bot.registerCommand("plugins", self.cmd_plugins)
 
+        self.bot.registerCommand("password", self.cmd_password, True)
         self.bot.registerCommand("login", self.cmd_login, True)
         self.bot.registerCommand("reload", self.cmd_reload, True)
         self.bot.registerCommand("die", self.cmd_die, True)
@@ -73,21 +73,27 @@ class CorePlugin:
     def cmd_help(self, issuedBy, data):
         """[command] - displays this message"""
         if data == "":
+            pref = self.bot.prefixes[0]
             for p in self.bot.plugins:
-                self.bot.reply("[{}] {}".format(p.name, ", ".join(self.bot.prefixes[0] + c.name for c in p.commands)))
+                cmds = [pref + c.name + ("*" if c.password else "")
+                        for c in p.commands]
+                self.bot.reply("[{}] {}".format(p.name, ", ".join(cmds)))
         else:
             for p in self.bot.plugins:
                 for c in p.commands:
                     if data == c.name:
-                        self.bot.reply("[{}] {}{} {}".format(p.name, self.bot.prefixes[0], c.name, c.function.__doc__))
+                        self.bot.reply(
+                            "[{}] {}{} {}".format(
+                                p.name, self.bot.prefixes[0],
+                                c.name, c.function.__doc__)
+                        )
                         return
             self.bot.reply("Command not found: " + data)
 
     def cmd_plugins(self, issuedBy, data):
         """lists all the currently loaded plugins"""
-        self.bot.reply("Plugins: " + ", ".join(p.name for p in self.bot.plugins))
-
-
+        self.bot.reply("Plugins: " +
+                       ", ".join(p.name for p in self.bot.plugins))
 
     """
     #------------------------------------------#
@@ -95,11 +101,18 @@ class CorePlugin:
     #------------------------------------------#
     """
 
+    def cmd_password(self, issuedBy, data):
+        """displays the bot's password"""
+        self.bot.pm(issuedBy, "My password is: " + self.bot.password)
+
     def cmd_login(self, issuedBy, data):
         """logs you in"""
-        if issuedBy not in self.bot.loggedin:
-            self.bot.loggedin.append(issuedBy)
-            self.bot.reply("{} has logged in".format(issuedBy))
+        # The login function is special in that it gets the full user object,
+        # not just the nick
+        host = issuedBy.host
+        if host not in self.bot.loggedin:
+            self.bot.loggedin.append(host)
+            self.bot.reply("{} has logged in".format(issuedBy.nick))
         else:
             self.bot.reply("You are already logged in")
 
